@@ -167,7 +167,7 @@ class ERC1319Registry(ABC):
     @abstractmethod
     def _get_all_release_ids(self, package_name: str) -> Iterable[bytes]:
         """
-        Returns a tuple containg all of the release ids belonging to the given package name,
+        Returns a tuple containing all of the release ids belonging to the given package name,
         if the package has releases on the connected registry.
 
         * Parameters:
@@ -389,13 +389,13 @@ class PM(Module):
             addr_lookup = self.web3.ens.address(str(address))
             if not addr_lookup:
                 raise NameNotFound(
-                    "No address found after ENS lookup for name: {0}.".format(address)
+                    f"No address found after ENS lookup for name: {address!r}."
                 )
             self.registry = SimpleRegistry(addr_lookup, self.web3)
         else:
             raise PMError(
                 "Expected a canonical/checksummed address or ENS name for the address, "
-                "instead received {0}.".format(type(address))
+                f"instead received {type(address)}."
             )
 
     def deploy_and_set_registry(self) -> ChecksumAddress:
